#
# spec file for package rapidjson
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           rapidjson
Version:        1.1.0
Release:        4.5
Summary:        JSON parser and generator for C++
License:        MIT
Group:          Development/Libraries/C and C++
URL:            http://rapidjson.org/
Source0:        https://github.com/miloyip/rapidjson/archive/v%{version}.tar.gz
Patch0:         remove_arch_specific_flags.patch
Patch1:         fix_compilation_sle11sp4.patch
Patch2:         fix_compilation_gcc7.patch
# PATCH-FIX-UPSTREAM -- ignore_gcc8_warnings.patch -- Ignore GCC 8 warnings.
Patch3:         ignore_gcc8_warnings.patch
Patch10:        fix_install_paths.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig

%description
RapidJSON is a JSON parser and generator for C++. It was inspired by RapidXml.

* It supports both SAX and DOM style API. The SAX parser is only a
  half thousand lines of code.
* It optionally supports SSE2/SSE4.2 for acceleration.
* Header-only implementation. It does not depend on STL.
* Each JSON value occupies exactly 16/20 bytes for most 32/64-bit
  machines (excluding text string). By default, it uses a memory
  allocator, and the parser allocates memory compactly during
  parsing.
* It supports UTF-8, UTF-16, UTF-32 (LE & BE), and their detection,
  validation and transcoding internally. For example, you can read a
  UTF-8 file and let RapidJSON transcode the JSON strings into UTF-16
  in the DOM. It also supports surrogates and "\u0000" (null
  character).

%package devel
Summary:        Header files for rapidjson, a JSON parser and generator for C++
Group:          Development/Libraries/C and C++
Provides:       %{name} = %{version}
%if 0%{?suse_version} > 1200
BuildArch:      noarch
%endif

%description devel
RapidJSON is a header-only JSON parser and generator for C++.
This package contains development headers and examples.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch10 -p1

%build
%cmake -DDOC_INSTALL_DIR=%{_docdir}/%{name}
make %{?_smp_mflags}

%install
%cmake_install
rm -f %{buildroot}%{_includedir}/%{name}/*.orig

%files devel
%defattr(-,root,root)
%if 0%{?suse_version} < 1500
%doc license.txt
%else
%license license.txt
%endif
# %license license.txt
%dir %{_datadir}/cmake/RapidJSON
%{_datadir}/cmake/RapidJSON/RapidJSONConfig.cmake
%{_datadir}/cmake/RapidJSON/RapidJSONConfigVersion.cmake
%{_datadir}/pkgconfig/RapidJSON.pc
%{_includedir}/%{name}
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/*

%changelog
* Wed Dec 12 2018 jengelh@inai.de
- Trim bias from description.
* Tue Dec 11 2018 mmnelemane@suse.com
- Fix build for SLE_12_SP2:
  * use %%doc for license file to fix build for older distro
* Mon Jun 18 2018 christophe@krop.fr
- Add upstream's patch ignore_gcc8_warnings.patch.
* Fri Jun  2 2017 christophe@krop.fr
- Add fix_compilation_gcc7.patch. Fixes build with GCC >= 7.0
* Mon Oct 10 2016 adam.majer@suse.de
- Added BuildRoot so we can actually build for SLE11
* Fri Sep 30 2016 adam.majer@suse.de
- New upstream version 1.1.0
  * Added JSON Pointer
  * Added JSON Schema
  * Added relaxed JSON syntax (comment, trailing comma,
    NaN/Infinity)
  * Iterating array/object with C++11 Range-based for loop
  * Reduce memory overhead of each Value from 24 bytes to 16 bytes
    in x86-64 architecture.
  * full changeset at
    https://github.com/miloyip/rapidjson/releases/tag/v1.1.0
- remove_arch_specific_flags.patch: remove architecture specific
  compiler flags.
- merge doc into devel package, it only adds about 20kB
* Wed Apr 20 2016 tbechtold@suse.com
- Initial packaging (version 1.0.2)
